/*
 * Socket used to communicate
 */
#undef DEFPORT

/*
 * Hostname of console server
 */
#undef MASTERHOST

/*
 * Config file path
 */
#undef CONFIGFILE

/*
 * Password file path
 */
#undef PASSWDFILE

/*
 * Logfile path
 */
#undef LOGFILEPATH

/*
 * Number of consoles per child process
 */
#undef MAXMEMB

/*
 * Number of child processes
 */
#undef MAXGRP

/*
 * Clear parity (high-bit) [true/false setting]
 */
#undef CPARITY

/*
 * TCP connection timeout
 */
#undef CONNECTTIMEOUT

/*
 * pidfile to write to
 */
#undef PIDFILE
